# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-14 18:41
from __future__ import unicode_literals

from django.db import migrations, models
import localflavor.us.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address_1', models.CharField(max_length=128, verbose_name='address')),
                ('address_2', models.CharField(blank=True, max_length=128, verbose_name="address cont'd")),
                ('city', models.CharField(max_length=64, verbose_name='city')),
                ('state', localflavor.us.models.USStateField(default='NY', verbose_name='state')),
                ('zip_code', models.CharField(max_length=10)),
                ('phone_number', localflavor.us.models.PhoneNumberField()),
                ('customer_name', models.CharField(help_text="Customer's last name", max_length=128)),
            ],
        ),
    ]



from django.contrib import admin
from .forms import ZipAdminForm
from .models import Address


class AddressAdmin(admin.ModelAdmin):
    """
    Addres admin page. This uses ZipAdminForm for the address
    form. Currently designed for US addresses only. For non US
    states just ignore the State.
    """
    form = ZipAdminForm
    list_display = ('state', 'city', 'address_1',)
    list_filter = ('city', 'state', 'zip_code',)
    search_fields = ('address_1', 'city', 'state', 'zip_code')

    def get_changelist_form(self, request, **kwargs):
        return ZipAdminForm

admin.site.register(Address, AddressAdmin)



from django import forms
from .models import Address
from localflavor.us.forms import USZipCodeField


class ZipAdminForm(forms.ModelForm):
    """
    Form for zip code in admin site
    """
    class Meta:
        model = Address
        widget = {
            'zip_code': USZipCodeField(),
        }
        fields = ('address_1', 'address_2', 'city', 'state', 'zip_code',
                  'phone_number', 'customer_name')



from django.db import models
from localflavor.us.models import USStateField
from localflavor.us.models import PhoneNumberField
from django.utils.translation import ugettext as _


class Address(models.Model):
    """
    Address model. This uses the US local flavor for the state field and
    phone numbers
    The customer_name is an optional attribute to keep track of the customer
    at this address without using a foreign key.
    """
    address_1 = models.CharField(_("address"), max_length=128)
    address_2 = models.CharField(_("address cont'd"), max_length=128,
                                 blank=True)
    city = models.CharField(_("city"), max_length=64)
    state = USStateField(_("state"), blank=True)
    zip_code = models.CharField(max_length=10)
    phone_number = PhoneNumberField()
    customer_name = models.CharField(max_length=128, blank=True,
                                     help_text='Customer\'s last name')

    def __str__(self):
        return "%s's address\n @ %s" % (self.customer_name, self.address_1)

    class Meta:
        verbose_name_plural = 'Addresses'
